@@ -29,7 +29,6 @@
 #include <KLocalizedString>
 
 #include <QMap>
-#include <QLoggingCategory>
 
 //FIXME:
 #define FIRST_ID 2 // first id, that is free of use, aka not defined above
@@ -58,7 +57,6 @@ KGameChat::KGameChat(KGame* g, int msgid, QWidget* parent, KChatBaseModel* model
     : KChatBase(parent, model, delegate),
       d( new KGameChatPrivate )
 {
- QLoggingCategory::setFilterRules(QStringLiteral("games.private.kgame.debug = true")); 
  init(g, msgid); 
 }
 
@@ -66,7 +64,6 @@ KGameChat::KGameChat(KGame* g, int msgid, KPlayer* fromPlayer, QWidget* parent,
     : KChatBase(parent,model,delegate),
       d( new KGameChatPrivate )
 {
- QLoggingCategory::setFilterRules(QStringLiteral("games.private.kgame.debug = true")); 
  init(g, msgid);
  setFromPlayer(fromPlayer);
 }
@@ -75,7 +72,6 @@ KGameChat::KGameChat(QWidget* parent)
     : KChatBase(parent),
       d( new KGameChatPrivate )
 {
- QLoggingCategory::setFilterRules(QStringLiteral("games.private.kgame.debug = true")); 
  init(0, -1);
 }
 
